==> rc-ui-lib-1.3.4.tgz: package/es/rate/Rate.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["count", "touchable", "onChange"];
import React, { useRef, useContext, useMemo } from 'react';
import classnames from 'classnames';
import useMergedState from '../hooks/use-merged-state';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
import { addUnit } from '../utils';
import { useTouch } from '../hooks/use-touch';
import useRefs from '../hooks/use-refs';
import usePassiveHandler from '../hooks/usePassiveHandler';
import Icon from '../icon';

var getRateStatus = function getRateStatus(value, index, allowHalf, readonly) {
  if (value >= index) {
    return {
      status: 'full',
      value: 1
    };
  }

  if (value + 0.5 >= index && allowHalf && !readonly) {
    return {
      status: 'half',
      value: 0.5
    };
  }

  if (value + 1 >= index && allowHalf && readonly) {
    var cardinal = Math.pow(10, 10);
    return {
      status: 'half',
      value: Math.round((value - index + 1) * cardinal) / cardinal
    };
  }

  return {
    status: 'void',
    value: 0
  };
};

var Rate = function Rate(_ref) {
  var count = _ref.count,
      touchable = _ref.touchable,
      onChange = _ref.onChange,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('rate', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useMergedState = useMergedState({
    value: props.value,
    defaultValue: props.defaultValue
  }),
      _useMergedState2 = _slicedToArray(_useMergedState, 2),
      value = _useMergedState2[0],
      setValue = _useMergedState2[1];

  var root = useRef(null);
  var touch = useTouch();

  var _useRefs = useRefs(),
      _useRefs2 = _slicedToArray(_useRefs, 2),
      itemRefs = _useRefs2[0],
      setItemRefs = _useRefs2[1];

  var untouchable = function untouchable() {
    return props.readonly || props.disabled || !touchable;
  };

  var starList = useMemo(function () {
    return Array(count).fill('').map(function (_, i) {
      return getRateStatus(value, i + 1, props.allowHalf, props.readonly);
    });
  }, [value, count]);
  var ranges = useRef();

  var updateRanges = function updateRanges() {
    var rects = itemRefs.map(function (item) {
      return item.getBoundingClientRect();
    });
    ranges.current = [];
    rects.forEach(function (rect, index) {
      if (props.allowHalf) {
        ranges.current.push({
          score: index + 0.5,
          left: rect.left
        }, {
          score: index + 1,
          left: rect.left + rect.width / 2
        });
      } else {
        ranges.current.push({
          score: index + 1,
          left: rect.left
        });
      }
    });
  };

  var getScoreByPosition = function getScoreByPosition(x) {
    // eslint-disable-next-line no-plusplus
    for (var i = ranges.current.length - 1; i > 0; i--) {
      if (x > ranges.current[i].left) {
        return ranges.current[i].score;
      }
    }

    return props.allowHalf ? 0.5 : 1;
  };

  var select = function select(index) {
    if (!props.disabled && !props.readonly && index !== value) {
      setValue(index);
      onChange === null || onChange === void 0 ? void 0 : onChange(index);
    }
  };

  var _onTouchStart = function onTouchStart(event) {
    if (untouchable()) {
      return;
    }

    touch.start(event);
    updateRanges();
  };

  var _onTouchMove = function onTouchMove(event) {
    if (untouchable()) {
      return;
    }

    touch.move(event);

    if (touch.isHorizontal()) {
      var clientX = event.touches[0].clientX;
      select(getScoreByPosition(clientX));
    }
  };

  usePassiveHandler();

  var renderStar = function renderStar(item, index) {
    var icon = props.icon,
        size = props.size,
        color = props.color,
        gutter = props.gutter,
        voidIcon = props.voidIcon,
        voidColor = props.voidColor,
        disabled = props.disabled,
        disabledColor = props.disabledColor,
        allowHalf = props.allowHalf,
        iconPrefix = props.iconPrefix;
    var score = index + 1;
    var isFull = item.status === 'full';
    var isVoid = item.status === 'void';
    var renderHalf = allowHalf && item.value > 0 && item.value < 1;
    var style;

    if (gutter && score !== +count) {
      style = {
        paddingRight: addUnit(gutter)
      };
    }

    var onClickItem = function onClickItem(event) {
      updateRanges();
      select(allowHalf ? getScoreByPosition(event.clientX) : score);
    };

    return /*#__PURE__*/React.createElement("div", {
      key: index,
      ref: setItemRefs(index),
      role: "radio",
      style: style,
      className: classnames(bem('item')),
      tabIndex: 0,
      "aria-setsize": parseInt(count === null || count === void 0 ? void 0 : count.toString(), 10),
      "aria-posinset": score,
      "aria-checked": !isVoid,
      onClick: onClickItem
    }, /*#__PURE__*/React.createElement(Icon, {
      size: size,
      name: isFull ? icon : voidIcon,
      className: classnames(bem('icon', {
        disabled: disabled,
        full: isFull
      })) // eslint-disable-next-line no-nested-ternary
      ,
      color: disabled ? disabledColor : isFull ? color : voidColor,
      classPrefix: iconPrefix
    }), renderHalf && /*#__PURE__*/React.createElement(Icon, {
      size: size,
      style: {
        width: "".concat(item.value, "em")
      },
      name: isVoid ? voidIcon : icon,
      className: classnames(bem('icon', ['half', {
        disabled: disabled,
        full: !isVoid
      }])) // eslint-disable-next-line no-nested-ternary
      ,
      color: disabled ? disabledColor : isVoid ? voidColor : color,
      classPrefix: iconPrefix
    }));
  };

  return /*#__PURE__*/React.createElement("div", {
    ref: root,
    role: "radiogroup",
    className: classnames(bem({
      readonly: props.readonly,
      disabled: props.disabled
    })),
    tabIndex: 0,
    onTouchStart: function onTouchStart(e) {
      return _onTouchStart(e);
    },
    onTouchMove: function onTouchMove(e) {
      return _onTouchMove(e);
    }
  }, starList.map(renderStar));
};

Rate.defaultProps = {
  size: 20,
  count: 5,
  gutter: 4,
  icon: 'star',
  voidIcon: 'star-o',
  touchable: true
};
export default Rate;

==> rc-ui-lib-1.3.5.tgz: package/es/rate/Rate.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["count", "touchable", "onChange"];
import React, { useRef, useContext, useMemo } from 'react';
import classnames from 'classnames';
import useMergedState from '../hooks/use-merged-state';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
import { addUnit } from '../utils';
import { useTouch } from '../hooks/use-touch';
import useRefs from '../hooks/use-refs';
import usePassiveHandler from '../hooks/usePassiveHandler';
import Icon from '../icon';
var getRateStatus = function getRateStatus(value, index, allowHalf, readonly) {
  if (value >= index) {
    return {
      status: 'full',
      value: 1
    };
  }
  if (value + 0.5 >= index && allowHalf && !readonly) {
    return {
      status: 'half',
      value: 0.5
    };
  }
  if (value + 1 >= index && allowHalf && readonly) {
    var cardinal = Math.pow(10, 10);
    return {
      status: 'half',
      value: Math.round((value - index + 1) * cardinal) / cardinal
    };
  }
  return {
    status: 'void',
    value: 0
  };
};
var Rate = function Rate(_ref) {
  var count = _ref.count,
    touchable = _ref.touchable,
    onChange = _ref.onChange,
    props = _objectWithoutProperties(_ref, _excluded);
  var _useContext = useContext(ConfigProviderContext),
    prefixCls = _useContext.prefixCls,
    createNamespace = _useContext.createNamespace;
  var _createNamespace = createNamespace('rate', prefixCls),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];
  var _useMergedState = useMergedState({
      value: props.value,
      defaultValue: props.defaultValue
    }),
    _useMergedState2 = _slicedToArray(_useMergedState, 2),
    value = _useMergedState2[0],
    setValue = _useMergedState2[1];
  var root = useRef(null);
  var touch = useTouch();
  var _useRefs = useRefs(),
    _useRefs2 = _slicedToArray(_useRefs, 2),
    itemRefs = _useRefs2[0],
    setItemRefs = _useRefs2[1];
  var untouchable = function untouchable() {
    return props.readonly || props.disabled || !touchable;
  };
  var starList = useMemo(function () {
    return Array(count).fill('').map(function (_, i) {
      return getRateStatus(value, i + 1, props.allowHalf, props.readonly);
    });
  }, [value, count]);
  var ranges = useRef();
  var updateRanges = function updateRanges() {
    var rects = itemRefs.map(function (item) {
      return item.getBoundingClientRect();
    });
    ranges.current = [];
    rects.forEach(function (rect, index) {
      if (props.allowHalf) {
        ranges.current.push({
          score: index + 0.5,
          left: rect.left
        }, {
          score: index + 1,
          left: rect.left + rect.width / 2
        });
      } else {
        ranges.current.push({
          score: index + 1,
          left: rect.left
        });
      }
    });
  };
  var getScoreByPosition = function getScoreByPosition(x) {
    // eslint-disable-next-line no-plusplus
    for (var i = ranges.current.length - 1; i > 0; i--) {
      if (x > ranges.current[i].left) {
        return ranges.current[i].score;
      }
    }
    return props.allowHalf ? 0.5 : 1;
  };
  var select = function select(index) {
    if (!props.disabled && !props.readonly && index !== value) {
      setValue(index);
      onChange === null || onChange === void 0 ? void 0 : onChange(index);
    }
  };
  var _onTouchStart = function onTouchStart(event) {
    if (untouchable()) {
      return;
    }
    touch.start(event);
    updateRanges();
  };
  var _onTouchMove = function onTouchMove(event) {
    if (untouchable()) {
      return;
    }
    touch.move(event);
    if (touch.isHorizontal()) {
      var clientX = event.touches[0].clientX;
      select(getScoreByPosition(clientX));
    }
  };
  usePassiveHandler();
  var renderStar = function renderStar(item, index) {
    var icon = props.icon,
      size = props.size,
      color = props.color,
      gutter = props.gutter,
      voidIcon = props.voidIcon,
      voidColor = props.voidColor,
      disabled = props.disabled,
      disabledColor = props.disabledColor,
      allowHalf = props.allowHalf,
      iconPrefix = props.iconPrefix;
    var score = index + 1;
    var isFull = item.status === 'full';
    var isVoid = item.status === 'void';
    var renderHalf = allowHalf && item.value > 0 && item.value < 1;
    var style;
    if (gutter && score !== +count) {
      style = {
        paddingRight: addUnit(gutter)
      };
    }
    var onClickItem = function onClickItem(event) {
      updateRanges();
      select(allowHalf ? getScoreByPosition(event.clientX) : score);
    };
    return /*#__PURE__*/React.createElement("div", {
      key: index,
      ref: setItemRefs(index),
      role: "radio",
      style: style,
      className: classnames(bem('item')),
      tabIndex: 0,
      "aria-setsize": parseInt(count === null || count === void 0 ? void 0 : count.toString(), 10),
      "aria-posinset": score,
      "aria-checked": !isVoid,
      onClick: onClickItem
    }, /*#__PURE__*/React.createElement(Icon, {
      size: size,
      name: isFull ? icon : voidIcon,
      className: classnames(bem('icon', {
        disabled: disabled,
        full: isFull
      }))
      // eslint-disable-next-line no-nested-ternary
      ,
      color: disabled ? disabledColor : isFull ? color : voidColor,
      classPrefix: iconPrefix
    }), renderHalf && /*#__PURE__*/React.createElement(Icon, {
      size: size,
      style: {
        width: "".concat(item.value, "em")
      },
      name: isVoid ? voidIcon : icon,
      className: classnames(bem('icon', ['half', {
        disabled: disabled,
        full: !isVoid
      }]))
      // eslint-disable-next-line no-nested-ternary
      ,
      color: disabled ? disabledColor : isVoid ? voidColor : color,
      classPrefix: iconPrefix
    }));
  };
  return /*#__PURE__*/React.createElement("div", {
    ref: root,
    role: "radiogroup",
    className: classnames(bem({
      readonly: props.readonly,
      disabled: props.disabled
    })),
    tabIndex: 0,
    onTouchStart: function onTouchStart(e) {
      return _onTouchStart(e);
    },
    onTouchMove: function onTouchMove(e) {
      return _onTouchMove(e);
    }
  }, starList.map(renderStar));
};
Rate.defaultProps = {
  size: 20,
  count: 5,
  gutter: 4,
  icon: 'star',
  voidIcon: 'star-o',
  touchable: true
};
export default Rate;
